# Changelog

## [unreleased] - [see changes](https://github.com/semgrep/mcp/compare/v0.2.0...HEAD)

- Resources [See README](README.md#resources)

## [0.2.0] - 2025-04-28

- fix potential path traversal `safe_join`

## [0.1.13] - 2025-04-07

- add `write_custom_semgrep_rule` prompt to MCP server

## [0.1.12] - 2025-04-06

- `-h` and `-v` now work for `--help` and `--version` respectively

## [0.1.11] - 2025-04-06

- This CHANGELOG file
